package com.loganmagnan.pluginbase;

import com.loganmagnan.pluginbase.menusystem.PlayerMenuUtil;
import com.loganmagnan.pluginbase.utils.ClassRegistrationUtils;
import com.loganmagnan.pluginbase.utils.ColorUtils;
import com.loganmagnan.pluginbase.utils.Utils;
import com.loganmagnan.pluginbase.utils.command.CommandFramework;
import com.loganmagnan.pluginbase.utils.config.FileConfig;
import com.loganmagnan.pluginbase.utils.config.file.Config;
import lombok.Getter;
import lombok.Setter;
import org.bukkit.entity.Player;
import org.bukkit.plugin.java.JavaPlugin;
import java.util.HashMap;

@Getter
@Setter
public class PluginBase extends JavaPlugin {

    // Main Class Instance
    @Getter private static PluginBase instance;

    // Configuration Files
    private Config mainConfig;
    private FileConfig messagesConfig;

    // Managers

    // Menu System
    private HashMap<Player, PlayerMenuUtil> playerMenuUtilMap = new HashMap<>();

    // Command Framework
    private CommandFramework commandFramework = new CommandFramework(this);

    @Override
    public void onEnable() {
        instance = this;

        this.saveDefaultConfig();
        this.mainConfig = new Config("config", this);
        this.messagesConfig = new FileConfig(this, "messages.yml");

        this.getServer().getConsoleSender().sendMessage(Utils.chatBar);
        this.getServer().getConsoleSender().sendMessage(ColorUtils.getMessageType("&dPluginBase &7- &av" + this.getDescription().getVersion()));
        this.getServer().getConsoleSender().sendMessage(ColorUtils.getMessageType("&7Made by &eLoganM Development"));
        this.getServer().getConsoleSender().sendMessage(Utils.chatBar);
        this.loadCommands();
        this.loadManagers();
        this.loadListeners();
        this.loadRunnables();
    }

    @Override
    public void onDisable() {
        instance = null;
    }

    private void loadCommands() {
        ClassRegistrationUtils.loadCommands("com.loganmagnan.pluginbase.commands");
    }

    private void loadManagers() {

    }

    private void loadListeners() {
        ClassRegistrationUtils.loadListeners("com.loganmagnan.pluginbase.listeners");
    }

    private void loadRunnables() {

    }

    public PlayerMenuUtil getPlayerMenuUtil(Player player) {
        PlayerMenuUtil playerMenuUtil;

        if (playerMenuUtilMap.containsKey(player)) {
            return playerMenuUtilMap.get(player);
        } else {
            playerMenuUtil = new PlayerMenuUtil(player);

            playerMenuUtilMap.put(player, playerMenuUtil);

            return playerMenuUtil;
        }
    }
}
